4.5. umbra.components.addons.tcpServerUi.tcpServerUi — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.5. umbra.components.addons.tcpServerUi.tcpServerUi

tcpServerUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `TCPServerUi` Component Interface class and others helper objects.

Others:

## 4.5.1. Module Attributes

`umbra.components.addons.tcpServerUi.tcpServerUi.` `LOGGER`

`umbra.components.addons.tcpServerUi.tcpServerUi.` `COMPONENT_UI_FILE`

## 4.5.2. Classes

class `umbra.components.addons.tcpServerUi.tcpServerUi.` `RequestsStackDataHandler`(request, client_address, server)

  Bases: `SocketServer.BaseRequestHandler`

  This class represents the default requests handler.

  `handle`()

    This method reimplements the `SocketServer.BaseRequestHandler.handle()` method.

    Returns: | Method success. ( Boolean )

class `umbra.components.addons.tcpServerUi.tcpServerUi.` `TCPServerUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `umbra.components.factory.tcpServerUi.tcpServerUi` Component Interface class.
  It provides various methods to operate the TCP Server.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `settingsSection`

    This method is the property for self.__settingsSection attribute.

    Returns: | self.__settingsSection. ( String )

  `preferencesManager`

    This method is the property for self.__preferencesManager attribute.

    Returns: | self.__preferencesManager. ( QWidget )

  `tcpServer`

    This method is the property for self.__tcpServer attribute.

    Returns: | self.__tcpServer. ( QWidget )

  `address`

    This method is the property for self.__address attribute.

    Returns: | self.__address. ( String )

  `port`

    This method is the property for self.__port attribute.

    Returns: | self.__port. ( Integer )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`()

    This method deactivates the Component.

    Returns: | Method success. ( Boolean )

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`()

    This method uninitializes the Component ui.

    Returns: | Method success. ( Boolean )

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`()

    This method removes the Component Widget from the engine.

    Returns: | Method success. ( Boolean )

  `onStartup`()

    This method is triggered on Framework startup.

  `onClose`()

    This method is triggered on Framework close.

  `startTcpServer`(port)

    This method starts the TCP server using given port.

    Parameters: | port – Port. ( Integer )
    Returns: | Method success. ( Boolean )

  `stopTcpServer`()

    This method stops the TCP server.

    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »